@@ -75,20 +75,39 @@ void close_all(void)
 
 static void recv_kernel(void)
 {
-    struct atm_vcc *vcc;
+#if 0
+    struct arequipa_msg msg;
     int size;
 
-    size = read(kernel,&vcc,sizeof(vcc));
+    size = read(kernel,&msg,sizeof(msg));
     if (size < 0) {
 	diag(COMPONENT,DIAG_ERROR,"read kernel: %s",strerror(errno));
 	return;
     }
-    if (size != sizeof(vcc))
+    if (size != sizeof(msg))
 	diag(COMPONENT,DIAG_FATAL,"kernel message has bad size (%d != %d)",
-	  size,sizeof(vcc));
-    diag(COMPONENT,DIAG_DEBUG,"Closing socket 0x%08lx",(unsigned long) vcc);
-    if (ioctl(kernel,AREQUIPA_CLS3RD,(unsigned long) vcc) < 0)
-	diag(COMPONENT,DIAG_ERROR,"ioctl AREQUIPA_CLS3RD: %s",strerror(errno));
+	  size,sizeof(msg));
+    switch (msg.type) {
+	case amt_close:
+	    diag(COMPONENT,DIAG_DEBUG,"Closing socket %p",msg.ptr);
+	    if (ioctl(kernel,AREQUIPA_CLS3RD,(unsigned long) msg.ptr) < 0)
+		diag(COMPONENT,DIAG_ERROR,"ioctl AREQUIPA_CLS3RD: %s",
+		  strerror(errno));
+	    break;
+	case amt_sync:
+	    diag(COMPONENT,DIAG_DEBUG,"Synchronizing with %p",msg.ptr);
+	    if (ioctl(kernel,AREQUIPA_SYNCACK,(unsigned long) msg.ptr) < 0)
+		diag(COMPONENT,DIAG_ERROR,"ioctl AREQUIPA_SYNCACK: %s",
+		  strerror(errno));
+	    break;
+	default:
+	    diag(COMPONENT,DIAG_FATAL,"unrecognized message type %d",
+	      (int) msg.type);
+    }
+#else
+    if (ioctl(kernel,AREQUIPA_WORK,0) < 0)
+	diag(COMPONENT,DIAG_ERROR,"ioctl AREQUIPA_WORK: %s",strerror(errno));
+#endif
 }
 
 
