@@ -18,7 +18,7 @@ int connect_vcc(struct sockaddr *remote,const struct atm_qos *qos,int timeout);
 int set_ip(int fd,int ip);
 int set_encap(int fd,int mode);
 void send_packet(int fd,void *data,int length);
-int ip_itf_info(int number,unsigned long *ip,unsigned long *netmask);
+int ip_itf_info(int number,unsigned long *ip,unsigned long *netmask,int *mtu);
 int get_local(int fd,struct sockaddr_atmsvc *addr);
 
 #endif
