@@ -35,10 +35,12 @@
 #ifndef MESSAGE_H
 #define MESSAGE_H
 
+#include "asn_incl.h"
+#include "rfc1155_smi.h"
 #include "rfc1157_snmp.h"
 
-#define ADDRESS_LEN 12
-#define ADDRESS_OID "\53\06\01\04\01\202\141\02\06\01\01\03"
+#define ADDRESS_LEN 13
+#define ADDRESS_OID "\53\06\01\04\01\202\141\02\06\01\01\03\0"
 
 extern int no_var_bindings;
 
