@@ -9,9 +9,9 @@
 
 /* System includes needed for types */
 #include <linux/atm.h>
-#include <linux/atmsap.h>
 
 /* Local includes needed for types */
+#include "atmsap.h"
 #include "units.h"
 #include "lane.h"
 
