@@ -1,6 +1,6 @@
 /* arequipa.c - AREQUIPA support functions */
  
-/* Written 1996 by Jean-Michel Pittet and Werner Almesberger, EPFL-LRC */
+/* Written 1996,1997 by Jean-Michel Pittet and Werner Almesberger, EPFL-LRC */
 
 
 #include <unistd.h>
@@ -69,5 +69,7 @@ int arequipa_expect(int sd,int on)
 
 int arequipa_close(int sd)
 {
-    return ioctl(sd,AREQUIPA_CLOSE,0);
+    if (ioctl(sd,AREQUIPA_CLOSE,0) < 0) return -1;
+    return ioctl(sd,AREQUIPA_SYNCREQ,0);
+    
 }
