@@ -1001,22 +1001,26 @@ static void data_poll(SSCOP_DSC *dsc,int s) /* 20.41-42 */
     /* K */
     curr = 0;
     i = dsc->vr_r;
-    while (NORM_RX(i) < NORM_RX(dsc->vr_h)) {
-	if (queue_lookup(&dsc->rx_buf,i)) {
-	    INC24(i);
-	    continue;
-	}
-	dsc->list[curr++] = htonl(i);
-	if (curr >= dsc->cf_max_stat) {
-	    send_pdu(dsc,SSCOP_STAT,dsc->list,curr*4);
-	    curr = 0;
+    if (i != dsc->vr_h) {
+	while (NORM_RX(i) < NORM_RX(dsc->vr_h)) {
+	    if (queue_lookup(&dsc->rx_buf,i)) {
+		INC24(i);
+		continue;
+	    }
 	    dsc->list[curr++] = htonl(i);
+	    if (curr >= dsc->cf_max_stat) {
+		send_pdu(dsc,SSCOP_STAT,dsc->list,curr*4);
+		curr = 0;
+		dsc->list[curr++] = htonl(i);
+	    }
+	    do INC24(i);
+	    while (i != dsc->vr_h && !queue_lookup(&dsc->rx_buf,i));
+	    if (i == dsc->vr_h) break; /* append is done right b4 send_pdu */
+	    dsc->list[curr++] = htonl(i);
+	    INC24(i); /* short-cut, since i < VR(H) && SD.N(S) == i in RB */
 	}
-	do INC24(i);
-	while (i != dsc->vr_h && !queue_lookup(&dsc->rx_buf,i));
 	dsc->list[curr++] = htonl(i);
     }
-    if (NORM_RX(i) > NORM_RX(dsc->vr_h)) dsc->list[curr++] = htonl(i);
     send_pdu(dsc,SSCOP_STAT,dsc->list,curr*4);
 }
 
