@@ -355,7 +355,7 @@ void from_kernel(struct atmsvc_msg *msg,int size)
 	    if (msg->listen_vcc == curr->id && curr->state == ss_listening)
 		break;
     }
-    diag(COMPONENT,DIAG_DEBUG,"FROM KERNEL: %s for socket 0x%p (0x%lx/0x%lx) "
+    diag(COMPONENT,DIAG_DEBUG,"FROM KERNEL: %s for socket %p (0x%lx/0x%lx) "
       "in state %s",as_name[msg->type],curr,msg->vcc,msg->listen_vcc,
       state_name[curr ? curr->state : ss_null]);
     msg->svc.sas_addr.blli = msg->local.sas_addr.blli = NULL;
