@@ -75,14 +75,14 @@ void free_sock(SOCKET *sock)
 {
     SOCKET **walk;
 
-    diag(COMPONENT,DIAG_DEBUG,"freeing socket 0x%lx@0x%p",sock->id,sock);
+    diag(COMPONENT,DIAG_DEBUG,"freeing socket 0x%lx@%p",sock->id,sock);
     for (walk = &sockets; *walk != sock; walk = &(*walk)->next);
     if (!*walk)
 	diag(COMPONENT,DIAG_FATAL,
 	  "INTERNAL ERROR: freeing non-existing socket 0x%lx",sock->id);
     *walk = sock->next;
     if (sock->conn_timer) {
-	diag(COMPONENT,DIAG_ERROR,"socket 0x%lx has timer (0x%p) running",
+	diag(COMPONENT,DIAG_ERROR,"socket 0x%lx has timer (%p) running",
 	  sock->id,sock->conn_timer->callback);
 	stop_timer(sock->conn_timer);
     }
