@@ -111,7 +111,7 @@ static void append_svc(const struct sockaddr_atmsvc *svc)
     char buffer[MAX_ATM_ADDR_LEN+1];
 
     if (atm2text(buffer,MAX_ATM_ADDR_LEN+1,(struct sockaddr *) svc,
-      A2T_NAME | A2T_PRETTY) < 0) strcpy(buffer,"<invalid>");
+      A2T_NAME | A2T_LOCAL | A2T_PRETTY) < 0) strcpy(buffer,"<invalid>");
     append("%s\n",buffer);
 }
 
